//= require <gettexthelper>
Ext.namespace('TimedEvents', 'TimedEvents.config');

function _(msgid)
{
    if (TimedEvents.config.gt === undefined) {
        return msgid;
    }

    return TimedEvents.config.gt.gettext(msgid);
}

function pad(n) {
    return n < 10 ? '0' + n: n
}
 
TimedEvents.config.groups = {
    "VARIABLE"  : 0,
    "LIGHT"     : 1,
    "SHADOW"    : 2,
    "CLIMATE"   : 3,
    "AUDIO"     : 4,
    "VIDEO"     : 5,
    "SECURITY"  : 6,
    "ACCESS"    : 7,
    "JOKER"     : 8,
    "WHITE"     : 9,
    "DISPLAYS"  : 10
};

TimedEvents.config.scenes = {
    "DEC"       : 11,
    "INC"       : 12,
    "MIN"       : 13,
    "MAX"       : 14,
    "STOP"      : 15,
    "T0_S0"     : 0,
    "T0_S1"     : 5,
    "T0_S2"     : 17,
    "T0_S3"     : 18,
    "T0_S4"     : 19,
    "SIG_BELL"  : 41,
    "ABSENT"    : 56
};


TimedEvents.ActionPanel = Ext.extend(Ext.Panel,
{
    constructor: function(config) 
    {
        this.parentForm = config.parentForm;

        this.changingDesc = new Ext.Panel(
        {
            scope: this,
            height: 20,
            bodyBorder: false,
            autoEl: 'span',
            cls: 'x-green-text black-text',
            html: _("Value") + ": " + "0%"
        });

        this.unitCombo = new Ext.form.ComboBox(
        {
            scope: this,
            editable: false,
            triggerAction: 'all',
            mode: 'local',
            ref: 'unit',
            width: 160,
            fieldLabel: _("Action"),
            forceSelection: true,
            submitValue: false,
            allowBlank: false,
            emptyText: _("Select unit") + "...",
            store: new Ext.data.ArrayStore(
            {
                fields: [ 'id', 'displayText' ],
                data: 
                [
                    [ 'group', _("Group") ],
                    [ 'scene', _("Scene") ] 
                ]
            }),
            displayField: 'displayText',
            hiddenField: 'id',
            valueField: 'id',
            listeners: 
            {
                select: this.updateDesc.createDelegate(this)
            },
            value: 'group'
        });

        this.groupCombo = new Ext.form.ComboBox(
        {
            editable: false,
            mode: 'local',
            ref: 'group',
            width: 160,
            hideLabel: true,
            submitValue: false,
            forceSelection: true,
            triggerAction: 'all',
            allowBlank: false,
            store: new Ext.data.ArrayStore(
            {
                fields: [ 'id', 'displayText' ],
                data: 
                [
                    [ TimedEvents.config.groups.LIGHT, _("Light") ]
                ]
            }),
            displayField: 'displayText',
            valueField: 'id',
            value: TimedEvents.config.groups.LIGHT
        });

        this.sceneCombo = new Ext.form.ComboBox(
        {
            editable: false,
            hidden: false,
            mode: 'local',
            width: 160,
            hideLabel: true,
            submitValue: false,
            forceSelection: true,
            triggerAction: 'all',
            allowBlank: false,
            store: new Ext.data.ArrayStore(
            {
                fields: [ 'id', 'displayText' ],
                data: 
                [
                    [ TimedEvents.config.scenes.MAX, _("On") ],
                    [ TimedEvents.config.scenes.MIN, _("Off") ],
                    [ TimedEvents.config.scenes.INC, _("Dim up") ],
                    [ TimedEvents.config.scenes.DEC, _("Dim down") ],
                    [ TimedEvents.config.scenes.T0_S0, _("Scene") + " 0" ],
                    [ TimedEvents.config.scenes.T0_S1, _("Scene") + " 1" ],
                    [ TimedEvents.config.scenes.T0_S2, _("Scene") + " 2" ],
                    [ TimedEvents.config.scenes.T0_S3, _("Scene") + " 3" ],
                    [ TimedEvents.config.scenes.T0_S4, _("Scene") + " 4" ]
                ]
            }),
            displayField: 'displayText',
            valueField: 'id',
            value: TimedEvents.config.scenes.MAX
        });

        this.value = new Ext.form.SliderField(
        {
            hideLabel: true,
            scope: this,
            width: 160,
            height: 20,
            minValue: 0,
            increment: 1,
            maxValue: 100,
            submitValue: false,
            tipText: function(thumb) {
                return String.format('{0}%', thumb.value);
            }
        });

        this.value.slider.on('changeComplete', 
                function(slider, newVal, thumb) 
                { 
                    this.changingDesc.update(_("Value") + ": " + newVal + "%");
                }, 
                this
        );

        this.zoneCombo = new Ext.form.ComboBox(
        {
            xtype: 'combo',
            hideLabel: true,
            submitValue: false,
            //lazyInit: true,
            mode: 'local',
            forceSelection: true,
            store: config.zoneStore,
            emptyText: _("Select zone")+
                      "...",
            triggerAction: 'all',
            allowBlank: false,
            typeAhead: true,
            displayField: 'name',
            valueField: 'id',
            hiddenName: 'zone',
            width:160 
        });

        this.scenePanel = new Ext.Panel(
        {
            xtype: 'panel',
            scope: this,
            width: 160,
            hidden: true,
            layout: 'form',
            bodyBorder: false,
            items: 
            [
                this.sceneCombo
            ]
        });

        this.valuePanel = new Ext.Panel(
        {
            xtype: 'panel',
            scope: this,
            width: 160,
            layout: 'form',
            bodyBorder: false,
            items: 
            [
                this.value
            ]
        });

        Ext.apply(this,
        {
            layout: 'table',
            bodyBorder: false,
            hideBorders: true,
            height: 50,
            scope: this,
            autoDestroy: true,
            layoutConfig: 
            {
                columns: 10 
            },
            items: 
            [
                // row 1
                {
                    xtype: 'box',
                    height: 20,
                    width: 19
                },
                {
                    xtype: 'panel',
                    height: 20,
                    bodyBorder: false,
                    autoEl: 'span',
                    cls: 'x-green-text black-text',
                    html: _("Unit") + ":"
                },
                {
                    xtype: 'box',
                    height: 20,
                    width: 10
                },
                {
                    xtype: 'panel',
                    height: 20,
                    bodyBorder: false,
                    autoEl: 'span',
                    cls: 'x-green-text black-text',
                    html: _("Zone") + ":"
                },
                {
                    xtype: 'box',
                    height: 20,
                    width: 10
                },
                {
                    xtype: 'panel',
                    height: 20,
                    bodyBorder: false,
                    autoEl: 'span',
                    cls: 'x-green-text black-text',
                    html: _("Group") + ":"
                },
                {
                    xtype: 'box',
                    height: 20,
                    width: 10
                },
                    this.changingDesc,
                {
                    xtype: 'box',
                    height: 20,
                    width: 10
                },
                {
                    xtype: 'box',
                    height: 20,
                    width: 10
                },

                // row 2
                {
                    xtype: 'panel',
                    layout: 'form',
                    bodyBorder: false,
                    colspan: 2,
                    items: 
                    [
                        this.unitCombo
                    ]
                },
                {
                    xtype: 'box',
                    height: 20,
                    width: 10
                },
                {
                    xtype: 'panel',
                    layout: 'form',
                    bodyBorder: false,
                    items: 
                    [
                        this.zoneCombo
                    ]
                },
                {
                    xtype: 'box',
                    height: 20,
                    width: 10
                },
                {
                    xtype: 'panel',
                    layout: 'form',
                    bodyBorder: false,
                    items: 
                    [
                        this.groupCombo
                    ]
                },
                {
                    xtype: 'box',
                    height: 20,
                    width: 10
                },
                {
                    xtype: 'panel',
                    bodyBorder: false,
                    layout: 'fit',
                    items: [
                        this.valuePanel,
                        this.scenePanel
                    ]
                },
                {
                    xtype: 'box',
                    height: 20,
                    width: 10
                },
                {
                    xtype: 'button',
                    text: _("Remove"),
                    tooltip: _("Remove this action"),
                    scope: this,
                    handler: function() {
                        this.parentForm.removeAction(this); 
                    }
                }
            ]
        });

        TimedEvents.ActionPanel.superclass.constructor.apply(this, arguments);
    },
    updateDesc: function(combo, record, index) 
    {
        if (record.get('id') === 'scene') 
        {
            this.changingDesc.update(_("Scene") + ":");
            this.valuePanel.setVisible(false);
            this.scenePanel.setVisible(true);
        }
        else
        {
            this.changingDesc.update(_("Value") + ": " + 
                                     this.value.getValue() + "%");
            this.scenePanel.setVisible(false);
            this.valuePanel.setVisible(true);
        }
    }
});

Ext.reg('actionpanel', TimedEvents.ActionPanel);

TimedEvents.DatePanel = Ext.extend(Ext.Panel,
{
    constructor: function(config)
    {
        this.parentForm = config.parentForm;

        var d = new Date();
       
        Ext.apply(this, 
        {
            layout: 'table',
            scope: this,
            hideBorders: true,
            bodyBorder: false,
            layoutConfig:
            {
                columns: 3
            },
            items:
            [
                { 
                    xtype: 'panel',
                    layout: 'form',
                    ref: 'date',
                    items:
                    [
                        {
                            xtype: 'datefield',
                            fieldLabel: _("Timer date"),
                            ref: 'timerDate',
                            format: 'd-m-Y',
                            width: 330,
                            minValue: pad(d.getDate()) + '-' + 
                                      pad(d.getMonth() + 1) + '-' +
                                      d.getFullYear(),
                            allowBlank: false
                        }
                    ]
                },
                {
                    xtype: 'box',
                    width: 10
                },
                {
                    xtype: 'button',
                    text: _("Remove"),
                    scope: this,
                    handler: function() 
                    {
                        this.parentForm.removeDate(this);
                    }
                },
                {
                    xtype: 'box',
                    height: 5,
                    colspan: 3
                }

            ]
        });

        TimedEvents.DatePanel.superclass.constructor.apply(this, arguments);
    },
    getValue: function()
    {
        return this.date.timerDate.getValue();
    }
});

Ext.reg('datepanel', TimedEvents.DatePanel);

TimedEvents.EventForm = Ext.extend(Ext.FormPanel,
{
    initComponent: function() 
    {

        this.actionCount = 0;
        this.dateCount = 0;
        this.loadingStructure = false;

        this.zoneStore = new Ext.data.Store(
        {
            sortInfo: { field:'id', direction:'ASC' },
            reader: new Ext.data.JsonReader(
            {
                root: "zones",
                fields: 
                [
                    { name: 'id' },
                    { name: 'name' }
                ]
            })
        });

        this.loadingStructure = true;
        Ext.Ajax.request(
        {
            url: '/json/apartment/getStructure',
            disableCaching: true,
            timeout: 300000,
            method: "GET",
            scope: this,
            success: function(result, request) 
            {
                try
                {
                    var jsonData = Ext.util.JSON.decode(result.responseText);
                    if (jsonData.ok)
                    {
                        var zones = [];
                        Ext.each(jsonData.result.apartment.zones, 
                            function(zone) 
                            {
                                if (zone.id !== 0)
                                {
                                    zones.push(
                                    {
                                        id: zone.id,
                                        name: zone.name ? zone.id + " - " + 
                                        zone.name: zone.id + " - " + _("Zone")
                                    });
                                }
                            }
                        );
                        this.zoneStore.loadData({ zones: zones });
                    }
                } 
                catch(err) 
                {
                    Ext.MessageBox.alert(_("Error"), 
                        _("Could not load apartment structure") + ": \"" + 
                        err + "\"");
                }
                this.loadingStructure = false;
            },
            failure: function(result, request) {
                this.loadingStructure = false;
                Ext.MessageBox.alert(_("Error"), 
                    _("Could not load apartment structure") + ": \"" + 
                    request.url + "\"");
            }
        });


        this.recurrenceCombo = new Ext.form.ComboBox(
        {
            scope: this,
            editable: false,
            triggerAction: 'all',
            mode: 'local',
            width: 330,
            name: 'recurrence',
            fieldLabel: _("Recurrence"),
            forceSelection: true,
            allowBlank: false,
            store: new Ext.data.ArrayStore(
            {
                fields: [ 'id', 'displayText' ],
                data: 
                [
                    [ 'regular_wk', _("Periodic (weekly)") ],
                    [ 'irregular', _("Irregular") ] 
                ]
            }),
            displayField: 'displayText',
            valueField: 'id',
            hiddenName: 'recurrence',
            listeners: 
            {
                select: this.showTimeSelection.createDelegate(this)
            },
            value: 'regular_wk'
        });


        this.irregular = new Ext.Panel(
        {
            bodyBorder: false,
            hidden: true,
            layout: 'form',
            //height: 200,
            ref: 'irregular',
            autoScroll: true,
            scope: this,
            items:
            [
                {
                    xtype: 'button',
                    text: _("Add date"),
                    tooltip: _("Add new date"),
                    scope: this,
                    handler: function()
                    {
                        this.irregular.dateHolder.add(
                            new TimedEvents.DatePanel( { parentForm: this } )
                        );
                        this.irregular.dateHolder.doLayout();
                        this.dateCount++;
                    }
                },
                {
                    xtype: 'box',
                    hteight: 5
                },
                {
                    xtype: 'panel',
                    bodyBorder: false,
                    hideBorders: true,
                    ref: 'dateHolder',
                    scope: this
                }
            ] 
        });

        this.periodicWeekly = new Ext.Panel(
        {
            hideBorders: true,
            bodyBorder: false,
            layout: 'table',
            layoutConfig: 
            {
                columns: 3
            },
            items:
            [
                {
                    xtype: 'panel',
                    layout: 'form',
                    items: 
                    [
                        {
                            xtype: 'checkbox',
                            name: 'MO',
                            boxLabel: _("Monday"),
                        },
                        {
                            xtype: 'checkbox',
                            name: 'TU',
                            boxLabel: _("Tuesday"),
                        },
                        {
                            xtype: 'checkbox',
                            name: 'WE',
                            boxLabel: _("Wednesday"),
                        }
                    ]
                },
                {
                    xtype: 'panel',
                    layout: 'form',
                    items: 
                    [
                        {
                            xtype: 'checkbox',
                            name: 'TH',
                            boxLabel: _("Thursday"),
                        },
                        {
                            xtype: 'checkbox',
                            name: 'FR',
                            boxLabel: _("Friday"),
                        },
                        {
                            xtype: 'checkbox',
                            name: 'SA',
                            boxLabel: _("Saturday"),
                        }
                    ]
                },
                {
                    xtype: 'panel',
                    layout: 'form',
                    items: 
                    [
                        {
                            xtype: 'checkbox',
                            name: 'SU',
                            boxLabel: _("Sunday"),
                        },
                        {
                            xtype: 'box',
                            height: 50
                        }
                    ]
                }

            ]
        });

        Ext.apply(this, 
        {
            autoScroll: true,
            bodyBorder: false,
            hideBorders: true,
            items: 
            [
                { 
                    xtype: 'panel',
                    padding: 6,
                    bodyBorder: false,
                    layout: 'form',
                    scope: this,
                    ref: 'mainPanel',
                    items: 
                    [
                        {
                            xtype: 'fieldset',
                            scope: this,
                            ref: 'timer',
                            title: _("Timer"),
                            items:
                            [
                                {
                                    xtype: 'textfield',
                                    width: 330,
                                    ref: 'timerName',
                                    allowBlank: false,
                                    fieldLabel: _("Timer name"),
                                    padding: 6
                                }
                            ]
                        },
                        {
                            xtype: 'fieldset',
                            title: _("Timer actions"),
                            bodyBorder: false,
                            //layout: 'fit',
                            //height: 200,
                            ref: 'actionHolder',
                            autoScroll: true,
                            scope: this,
                            items: 
                            [
                                {
                                    xtype: 'button',

                                    text: _("Add action"),
                                    tooltip: _("Add new action"),
                                    scope: this,
                                    handler: function() 
                                    {
                                        this.mainPanel.actionHolder.add(
                                            new TimedEvents.ActionPanel(
                                            {
                                                zoneStore: this.zoneStore,
                                                parentForm: this
                                            })
                                        );
                                        this.mainPanel.actionHolder.doLayout();
                                        this.actionCount++;
                                    }
                                }
                            ] 
                        }, // actionHolder panel
                        {
                            xtype: 'fieldset',
                            scope: this,
                            title: _("Time settings"),
                            ref: 'timeSettings',
                            items:
                            [
                                {
                                    xtype: 'timefield',
                                    fieldLabel: _("Trigger time"),
                                    format: 'H:i:s',
                                    ref: 'trigger',
                                    width: 330,
                                    allowBlank: false
                                },
                                this.recurrenceCombo,
                                {
                                    xtype: 'box',
                                    height: 5
                                },
                                this.periodicWeekly,
                                this.irregular
                            ]
                        } // date time fieldset
                    ]
                }
            ]
        });

        TimedEvents.EventForm.superclass.initComponent.apply(this, arguments);
    },
    removeAction: function(action) 
    {
        this.mainPanel.actionHolder.remove(action);
        this.mainPanel.actionHolder.doLayout();
        this.actionCount--;
        if (this.actionCount < 0) 
        {
            this.actionCount = 0;
        }
    },
    removeDate: function(date)
    {
        this.irregular.dateHolder.remove(date);
        this.irregular.dateHolder.doLayout();
        this.dateCount--;
        if (this.dateCount < 0)
        {
            this.dateCount = 0;
        }
    },
    showTimeSelection: function(combo, record, index)
    {
        if (record.get('id') === 'irregular') 
        {
            this.periodicWeekly.setVisible(false);
            this.irregular.setVisible(true);
        }
        else
        {
            this.irregular.setVisible(false);
            this.irregular.dateHolder.removeAll();
            this.dateCount = 0;
            this.periodicWeekly.setVisible(true);
        }
    },
    getActionData: function()
    {
        // process actions
        var counter = 0;
        var actions = {};
        var actionParameters = [];
        do
        {
            var action = this.mainPanel.actionHolder.get(counter);
            counter++;

            if (action === undefined) 
            {
                break;
            }

            if (action.getXType() != 'actionpanel')
            {
                continue;
            }


            var unit = action.unitCombo.getValue();
            var group = action.groupCombo.getValue();
            var zone = action.zoneCombo.getValue();

            var params = {};
            params.unit = unit;
            params.group = group;
            params.zone = zone;

            if (unit === 'group')
            {
                var val = action.value.getValue() / 100;
                val = val * 255;
                if (val < 0)
                {
                    val = 0;
                } 
                else if (val > 255)
                {
                    val = 255;
                }

                params.value = Math.round(val);
            } 
            else if (unit === 'scene')
            {
                params.scene = action.sceneCombo.getValue();
            }

            actionParameters.push(params);

        } while (action !== undefined);

        actions.actions = actionParameters;
        return actions;
    },
    getDates: function()
    {
        var counter = 0;
        var dates = [];

        function pad(n) {
            return n < 10 ? '0' + n: n
        }

        do
        {
            var datepanel = this.irregular.dateHolder.get(counter);
            counter++;

            if (datepanel === undefined)
            {
                break;
            }

            if (datepanel.getXType() != 'datepanel')
            {
                continue;
            }
    
            var val = datepanel.getValue();

            dates.push(pad(val.getDate()) + '-' + 
                       pad(val.getMonth() + 1) + '-' +
                       val.getFullYear());

        } while (datepanel !== undefined);

        return dates;
    },
    getWeekdays: function()
    {
        var counter = 0;
        var days = [];
        do
        {
            var panel = this.periodicWeekly.get(counter);
            counter++;

            if (panel === undefined)
            {
                break;
            }

            if (panel.getXType() != 'panel')
            {
                continue;
            }

            var ccount = 0;
            do
            {
                var checkbox = panel.get(ccount);
                ccount++;
                if (checkbox === undefined)
                {
                    break;
                }

                if (checkbox.getXType() != 'checkbox')
                {
                    continue;
                }

                if (checkbox.getValue() === true)
                {
                    days.push(checkbox.getName());
                }

            } while (checkbox != undefined);
        } while (panel !== undefined);

        return days;
    },
    getRecurrenceData: function()
    {
        var recurrenceObj = {};
        var triggertime = this.mainPanel.timeSettings.trigger.getValue().split(':');
        console.log("Got trigger time: ", triggertime);
        var d = new Date();
        d.setHours(triggertime[0]);
        d.setMinutes(triggertime[1]);
        d.setSeconds(triggertime[2]);

        triggertime = pad(d.getUTCHours()) + ':' + pad(d.getUTCMinutes()) + 
                      ':' + pad(d.getUTCSeconds());

        recurrenceObj.triggerTime = triggertime;
        var recurrence = this.recurrenceCombo.getValue();
        recurrenceObj.recurrence = recurrence;
        if (recurrence === 'regular_wk')
        {
             recurrenceObj.weekdays = this.getWeekdays();
        }
        else if (recurrence === 'irregular')
        {
            recurrenceObj.dates = this.getDates();
        }

        return recurrenceObj;
    }
});

Ext.reg('eventform', TimedEvents.EventForm);

TimedEvents.MainPanel = Ext.extend(Ext.Panel,
{
    initComponent: function() 
    {
        Ext.apply(this,
        {
            layout: 'fit',
            title: _("Configure timed events"),
            items: 
            [
                {
                    xtype: 'panel',
                    autoEl: 'span',
                    cls: 'x-green-text black-text',
                    html: _("This add-on allows you to configure timed events.")
                }
            ],
            buttons: 
            [
                {
                    xtype: 'button',
                    text: _("Add new timed event"),
                    ref: 'addTimedEventButton',
                    handler: function()
                    {
                        var win = new Ext.Window(
                        {
                            title: _("Configure timed events"),
                            layout: 'fit',
                            hideBorders: true,
                            height: 500,
                            width: 900,
                            minHeight: 400,
                            minWidth: 800,
                            autoScroll: true,
                            scope: this,
                            items:
                            [
                                { 
                                    xtype: 'eventform',
                                    ref: 'eventForm'
                                }
                            ],
                            buttons:
                            [
                                {
                                    text: _("Save and activate"),
                                    scope: this,
                                    handler: function()
                                    {
                                        win.activateTimer();
                                    }
                                },
                                { 
                                    text: _("Cancel"),
                                    scope: this,
                                    handler: function() 
                                    {
                                        win.close();
                                        this.enable();
                                        this.findParentByType('timedeventsmainpanel').el.unmask();
                                    }
                                }
                            ],
                            activateTimer: function()
                            {
                                if (!this.eventForm.getForm().isValid())
                                {
                                    Ext.MessageBox.alert(_("Error"),
                                     _("Please fill out all mandatory fields"));
                                    return;
                                }

                                if (this.eventForm.actionCount === 0)
                                {
                                    Ext.MessageBox.alert(_("Error"),
                                    _("Please add at least one action"));
                                    return;
                                }
                                
                                var recurrence = 
                                    this.eventForm.getRecurrenceData();

                                if ((recurrence.recurrence === 'irregular') &&
                                    (recurrence.dates.length === 0))
                                {
                                    Ext.MessageBox.alert(_("Error"),
                                    _("The \"irregular\" recurrence requires" + 
                                      " at least one date selection"));
                                    return;
                                }

                                if ((recurrence.recurrence === 'regular_wk') &&
                                    (recurrence.weekdays.length === 0))
                                {
                                    Ext.MessageBox.alert(_("Error"),
                                    _("The \"periodic\" recurrence requires" + 
                                      " at least one weekday selection"));
                                    return;
                                }

                                var timername = 'timername=' + this.eventForm.mainPanel.timer.timerName.getValue() + ';';

                                var actions = this.eventForm.getActionData();

                                var a_param = 'actions=' + 
                                       encodeURIComponent(Ext.encode(actions)) +
                                       ';';
                                var r_param = 'recurrence=' +
                                    encodeURIComponent(Ext.encode(recurrence)); 

                                Ext.Ajax.request(
                                {
                                    url: '/json/event/raise',
                                    method: 'GET',
                                    scope: this,
                                    params: 
                                    { 
                                        name: 'addtimer',
                                        parameter: timername + a_param + r_param
                                    },
                                    success: function(action)
                                    {
                                        try
                                        {
                                            var jsonData = 
                                                Ext.util.JSON.decode(
                                                          action.responseText);
                                            if (jsonData.ok)
                                            {
                                                this.close();
                                                return;
                                            }
                                            {
                                                Ext.Msg.alert(_("Error"),
                                                    _("Failed to add timer"));
                                            }
                                        }
                                        catch (error)
                                        {
                                            Ext.Msg.alert(_("Error"),
                                                    _("Failed to add timer"));
                                        }
                                    },
                                    failure: function(action) 
                                    {
                                        Ext.Msg.alert(_("Error"),
                                                _("Failed to add timer, " + 
                                                  "please check if dSS is " + 
                                                  "still running"));
                                    }
                                });
                            }
                            // all ok, submit form 
                        });

                        win.on('beforedestroy',
                                function() 
                                { 
                                    this.findParentByType('timedeventsmainpanel').el.unmask(); 
                                    this.enable();
                                },
                                this);

                        this.disable();
                        this.findParentByType('timedeventsmainpanel').el.mask();
                        win.show(this);
                    }
                }
            ]
        });

        TimedEvents.MainPanel.superclass.initComponent.apply(this, arguments);
    }
});

Ext.reg('timedeventsmainpanel', TimedEvents.MainPanel);

Ext.onReady(
    function()
    {
        Ext.get('start').remove();
        this.viewport = new Ext.Viewport(
        {
            hideBorders: true,
            layout: 'border',
            items:
                [
                    {
                        xtype: 'box',
                        region: 'north',
                        height: 80,
                        autoEl: 
                        {
                            tag: 'div',
                            html: '<a href="http://digitalstrom.org/" alt="' + 
                                _("visit digitalSTROM.org") + 
                                '"><img id="logo" src="images/ds_logo.gif"' + 
                                'alt="dS-Logo"></a>' + 
                                '<h1><a href="http://digitalstrom.org/"' + 
                                ' alt="visit digitalSTROM.org">' + 
                                _("digitalSTROM Server - Timed Events") + '</a></h1>'
                        }
                    },
                    {
                        region: 'center',
                        xtype: 'timedeventsmainpanel'
                    }
                ]
        });
    }
);
